## v4.2.5 (2023-01-08)

## v4.2.4 (2022-09-29)

### Refactor

- moved to toolbox_utils.tsutils and complete pyproject.toml
- remove __future__
- moved to f strings
- astronomia -> src/astronomia, docsrc -> docs

## v4.2.3 (2021-08-02)

## v4.2.2 (2021-06-29)

## v4.2.1 (2020-10-03)

### Refactor

- Clearer comparisons.

### Fix

- Fixed detection of binary vs UTF files.

## v4.1.1 (2020-04-30)
